@@ -165,11 +165,9 @@ cv.mmpc <- function(target, dataset, wei = NULL, kfolds = 10, folds = NULL, alph
           conf_mmpc[[mmpc_conf_id]]$performances[k] <- performance
         }
     }
-    #clear the hashmap and garbages
-    if ( !is.null(mmpcHashMap$pvalue_hash) )   hash::clear(mmpcHashMap$pvalue_hash)
-    if ( !is.null(mmpcHashMap$stat_hash) )    hash::clear(mmpcHashMap$stat_hash)
-    rm(mmpcHashMap);
-    gc();
+    #clear the hashmap 
+    if ( !is.null(mmpcHashMap$pvalue_hash) )   mmpcHashMap$pvalue_hash <- NULL
+    if ( !is.null(mmpcHashMap$stat_hash) )     mmpcHashMap$stat_hash <- NULL
   }
   
   #finding the best performance for the metric  
