@@ -22,9 +22,9 @@ testIndQBinom = function(target, dataset, xIndex, csIndex, wei = NULL, univariat
     csIndex2 = sort(csIndex2)
     xcs = c(xIndex,csIndex2)
     key = paste(as.character(xcs) , collapse=" ");
-    if( !is.null(stat_hash[[key]]) ){
-      stat = stat_hash[[key]];
-      pvalue = pvalue_hash[[key]];    
+    if( !is.null(stat_hash[key]) ){
+      stat = stat_hash[key];
+      pvalue = pvalue_hash[key];    
       results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
@@ -32,8 +32,8 @@ testIndQBinom = function(target, dataset, xIndex, csIndex, wei = NULL, univariat
   
   if ( !is.na( match(xIndex, csIndex) ) ) {
     if( hash )  {      #update hash objects
-      stat_hash[[key]] <- 0;    #.set(stat_hash , key , 0)
-      pvalue_hash[[key]] <- log(1);   #.set(pvalue_hash , key , 1)
+      stat_hash[key] <- 0;    #.set(stat_hash , key , 0)
+      pvalue_hash[key] <- log(1);   #.set(pvalue_hash , key , 1)
     }
     results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
@@ -53,8 +53,8 @@ testIndQBinom = function(target, dataset, xIndex, csIndex, wei = NULL, univariat
     if ( is.null(dim(cs)[2]) ) {    #cs is a vector
       if ( identical(x, cs) )  {   #if(!any(x == cs) == FALSE)
         if ( hash ) {    #update hash objects
-          stat_hash[[key]] <- 0;    #.set(stat_hash , key , 0)
-          pvalue_hash[[key]] <- log(1);     #.set(pvalue_hash , key , 1)
+          stat_hash[key] <- 0;    #.set(stat_hash , key , 0)
+          pvalue_hash[key] <- log(1);     #.set(pvalue_hash , key , 1)
         }
         results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         return(results);
@@ -63,8 +63,8 @@ testIndQBinom = function(target, dataset, xIndex, csIndex, wei = NULL, univariat
       for (col in 1:dim(cs)[2]) {
         if (identical(x, cs[, col]) ) {    #if(!any(x == cs) == FALSE
           if( hash ) {      #update hash objects
-            stat_hash[[key]] <- 0;   #.set(stat_hash , key , 0)
-            pvalue_hash[[key]] <- log(1);   #.set(pvalue_hash , key , 1)
+            stat_hash[key] <- 0;   #.set(stat_hash , key , 0)
+            pvalue_hash[key] <- log(1);   #.set(pvalue_hash , key , 1)
           }
           results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
           return(results);
@@ -92,8 +92,8 @@ testIndQBinom = function(target, dataset, xIndex, csIndex, wei = NULL, univariat
   } else {
     #update hash objects
     if ( hash )  {
-      stat_hash[[key]] <- stat;      #.set(stat_hash , key , stat)
-      pvalue_hash[[key]] <- pvalue;        #.set(pvalue_hash , key , pvalue)
+      stat_hash[key] <- stat;      #.set(stat_hash , key , stat)
+      pvalue_hash[key] <- pvalue;        #.set(pvalue_hash , key , pvalue)
     }
   }
   #testerrorcaseintrycatch(4);
